]> git.sesse.net Git - cubemap/blobdiff - server.h
Add a simple HTTP endpoint that returns a very short string.
[cubemap] / server.h
index cfc9d25160413a5ede6408213971a9d6bebed98f..7297fd7797daf3adaf73738da93eb861fca89ad6 100644 (file)
--- a/server.h
+++ b/server.h
@@ -61,6 +61,7 @@ public:
        void set_backlog_size(int stream_index, size_t new_size);
        void set_prebuffering_bytes(int stream_index, size_t new_amount);
        void set_encoding(int stream_index, Stream::Encoding encoding);
+       void add_ping(const std::string &url, const std::string &allow_origin);
 
 private:
        // Mutex protecting queued_add_clients.
@@ -87,7 +88,10 @@ private:
        std::vector<Stream *> streams;
 
        // Map from URL to index into <streams>.
-       std::map<std::string, int> url_map;
+       std::map<std::string, int> stream_url_map;
+
+       // Map from URL to CORS Allow-Origin header (or empty string).
+       std::map<std::string, std::string> ping_url_map;
 
        // Map from file descriptor to client.
        std::map<int, Client> clients;
@@ -130,7 +134,8 @@ private:
        // Close a given client socket, and clean up after it.
        void close_client(Client *client);
 
// Parse the HTTP request. Returns a HTTP status code (200/400/404).
        int parse_request(Client *client);
 
        // Construct the HTTP header, and set the client into
@@ -141,6 +146,9 @@ private:
        // the SENDING_SHORT_RESPONSE state.
        void construct_error(Client *client, int error_code);
 
+       // Construct a pong, and set the client into the SENDING_SHORT_RESPONSE state.
+       void construct_pong(Client *client);
+
        void process_queued_data();
        void skip_lost_data(Client *client);
@@ -130,7 +134,8 @@ private:
        void close_client(Client *client);
 
-       // Parse the HTTP request. Returns a HTTP status code (200/400/404).
+       // Parse the HTTP request. Returns a HTTP status code (200/400/404),
+       // or -200 for a pong (which should be answered with 200).
        int parse_request(Client *client);
 